SLiCAP Manual — SLiCAP 3.5.8 documentation

# SLiCAP Manual

SLiCAP is a S ymbolic Li near C ircuit A nalysis P rogram, intended to set-up and solve Analog circuit design equations, written in Python.

SLiCAP is distributed under the MIT license

## Contents

- SLiCAP Version 3.5
  - SLiCAP Version 3.5 release notes
  - Why should you use SLiCAP
  - How to use SLiCAP
  - SLiCAP Development Team
- SLiCAP user guide
  - Download, install, configure and test SLiCAP
  - Create a SLiCAP circuit object
  - Work with specifications
  - Work with parameters
  - Perform analysis
  - Create plots
  - Create reports
  - Work with analysis results
- SLiCAP Examples and Tutorials
- SLiCAP netlist syntax
  - Netlist lines
  - Devices and built-in models
  - Schematic capture for SLiCAP
- SLiCAP reference
  - SLiCAP.py
  - SLiCAPconfigure.py
  - SLiCAPdesignData.py
  - SLiCAPhtml.py
  - SLiCAPkicad.py
  - SLiCAPlatex.py
  - SLiCAPltspice.py
  - SLiCAPmath.py
  - SLiCAPngspice.py
  - SLiCAPplots.py
  - SLiCAPprotos.py
  - SLiCAPrst.py
  - SLiCAPshell.py